@@ -6,7 +6,7 @@ if sys.version_info < (3, 10):
 else:
     from importlib.metadata import entry_points
 
-__version__ = "0.0.4"
+__version__ = "0.0.7"
 
 class OutputType(Enum):
     SRD_OUTPUT_ANN = 0
@@ -21,6 +21,14 @@ OUTPUT_BINARY = OutputType.SRD_OUTPUT_BINARY
 OUTPUT_LOGIC = OutputType.SRD_OUTPUT_LOGIC
 OUTPUT_META = OutputType.SRD_OUTPUT_META
 
+SRD_CONF_SAMPLERATE = 1
+
+def SR_KHZ(num):
+    return num * 1000
+
+def SR_MHZ(num):
+    return SR_KHZ(num) * 1000
+
 class Decoder:
     # __init__() won't get called by subclasses
 
@@ -48,13 +56,18 @@ class Decoder:
             for cond in conds:
                 data_cond = {}
                 for k in cond:
-                    data_cond[self.decoder_channel_to_data_channel[k]] = cond[k]
+                    if k == "skip":
+                        data_cond["skip"] = cond[k]
+                    else:
+                        data_cond[self.decoder_channel_to_data_channel[k]] = cond[k]
                 data_conds.append(data_cond)
+
         raw_data = self.input.wait(data_conds)
         data = [None] * (len(self.channels) + len(getattr(self, "optional_channels", [])))
         for decoder_channel in self.decoder_channel_to_data_channel:
             data_channel = self.decoder_channel_to_data_channel[decoder_channel]
             data[decoder_channel] = raw_data[data_channel]
+
         return tuple(data)
 
     def put(self, startsample, endsample, output_id, data):
